@@ -26,11 +26,12 @@
 
 (eval-and-compile
   (eval
-   '(if (not (fboundp 'base64-encode-string))
-	(require 'base64))))
+   '(unless (fboundp 'base64-decode-string)
+      (require 'base64))))
+
 (require 'qp)
 (require 'mm-util)
-(require 'drums)
+(require 'ietf-drums)
 
 (defvar rfc2047-default-charset 'iso-8859-1
   "Default MIME charset -- does not need encoding.")
@@ -58,7 +59,7 @@ The values can be:
     (iso-8859-3 . Q)
     (iso-8859-4 . Q)
     (iso-8859-5 . B)
-    (koi8-r . Q)
+    (koi8-r . B)
     (iso-8859-7 . Q)
     (iso-8859-8 . Q)
     (iso-8859-9 . Q)
@@ -148,7 +149,8 @@ Should be called narrowed to the head of the message."
     (save-restriction
       (narrow-to-region b e)
       (goto-char (point-min))
-      (while (re-search-forward (concat "[^" drums-tspecials " \t\n]+") nil t)
+      (while (re-search-forward
+	      (concat "[^" ietf-drums-tspecials " \t\n]+") nil t)
 	(push
 	 (list (match-beginning 0) (match-end 0)
 	       (car
@@ -229,8 +231,8 @@ Should be called narrowed to the head of the message."
 	  (pop alist))
 	(goto-char (point-min))
 	(while (not (eobp))
-	  (forward-char 64)
-	  (search-backward "=" nil (- (point) 2))
+	  (goto-char (min (point-max) (+ 64 (point))))
+	  (search-backward "=" (- (point) 2) t)
 	  (unless (eobp)
 	    (insert "\n")))))))
 
@@ -302,12 +304,12 @@ Valid ENCODINGs are \"B\" and \"Q\".
 If your Emacs implementation can't decode CHARSET, it returns nil."
   (let ((cs (mm-charset-to-coding-system charset)))
     (when cs
+      (when (eq cs 'ascii)
+	(setq cs rfc2047-default-charset))
       (mm-decode-coding-string
        (cond
 	((equal "B" encoding)
-	 (if (fboundp 'base64-decode-string)
-	     (base64-decode-string string)
-	   (base64-decode string)))
+	 (base64-decode-string string))
 	((equal "Q" encoding)
 	 (quoted-printable-decode-string
 	  (mm-replace-chars-in-string string ?_ ? )))
